==> org.eclipse.fordiac.ide.fb.interpreter_3.0.0.202502102107.jar: src/org/eclipse/fordiac/ide/fb/interpreter/api/EventOccFactory.java <==
/*******************************************************************************
 * Copyright (c) 2022 Paul Pavlicek
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Paul Pavlicek
 *     - initial API and implementation and/or initial documentation
 *******************************************************************************/
package org.eclipse.fordiac.ide.fb.interpreter.api;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.fordiac.ide.fb.interpreter.OpSem.EventOccurrence;
import org.eclipse.fordiac.ide.fb.interpreter.OpSem.FBRuntimeAbstract;
import org.eclipse.fordiac.ide.fb.interpreter.OpSem.OperationalSemanticsFactory;
import org.eclipse.fordiac.ide.model.libraryElement.Event;

public final class EventOccFactory {

	public static EventOccurrence createFrom(final Event event, final FBRuntimeAbstract runtime) {
		final EventOccurrence createdEo = OperationalSemanticsFactory.eINSTANCE.createEventOccurrence();
		createdEo.setEvent(event);
		createdEo.setActive(true);
		createdEo.setIgnored(false);
		if (null != event) {
			createdEo.setParentFB(event.getFBNetworkElement());
		}
		createdEo.setFbRuntime(runtime);
		return createdEo;
	}

	public static EventOccurrence createFrom(final Event event) {
		return createFrom(event, null);
	}
	/** @param events
	 * @return */
	public static List<EventOccurrence> createFrom(final List<Event> events, final FBRuntimeAbstract initialRuntime) {
		if (null == events || events.isEmpty()) {
			return Collections.emptyList();
		}
		final List<EventOccurrence> createdEOs = new ArrayList<>();
		for (final Event e : events) {
			createdEOs.add(createFrom(e, null));
		}
		createdEOs.get(0).setFbRuntime(initialRuntime);
		return createdEOs;
	}

	private EventOccFactory() {
		throw new UnsupportedOperationException("this class should not be instantiated"); //$NON-NLS-1$
	}

}

==> org.eclipse.fordiac.ide.fb.interpreter_3.0.0.202512201229.jar: src/org/eclipse/fordiac/ide/fb/interpreter/api/EventOccFactory.java <==
/*******************************************************************************
 * Copyright (c) 2022, 2025 Paul Pavlicek
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Paul Pavlicek
 *     - initial API and implementation and/or initial documentation
 *******************************************************************************/
package org.eclipse.fordiac.ide.fb.interpreter.api;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.eclipse.fordiac.ide.fb.interpreter.OpSem.EventOccurrence;
import org.eclipse.fordiac.ide.fb.interpreter.OpSem.FBRuntimeAbstract;
import org.eclipse.fordiac.ide.fb.interpreter.OpSem.OperationalSemanticsFactory;
import org.eclipse.fordiac.ide.model.libraryElement.Event;

public final class EventOccFactory {

	public static EventOccurrence createFrom(final Event event, final FBRuntimeAbstract runtime) {
		final EventOccurrence createdEo = OperationalSemanticsFactory.eINSTANCE.createEventOccurrence();
		createdEo.setEvent(event);
		createdEo.setActive(true);
		createdEo.setIgnored(false);
		if (null != event) {
			createdEo.setParentFB(event.getBlockFBNetworkElement());
		}
		createdEo.setFbRuntime(runtime);
		return createdEo;
	}

	public static EventOccurrence createFrom(final Event event) {
		return createFrom(event, null);
	}

	/**
	 * @param events
	 * @return
	 */
	public static List<EventOccurrence> createFrom(final List<Event> events, final FBRuntimeAbstract initialRuntime) {
		if (null == events || events.isEmpty()) {
			return Collections.emptyList();
		}
		final List<EventOccurrence> createdEOs = new ArrayList<>();
		for (final Event e : events) {
			createdEOs.add(createFrom(e, null));
		}
		createdEOs.get(0).setFbRuntime(initialRuntime);
		return createdEOs;
	}

	private EventOccFactory() {
		throw new UnsupportedOperationException("this class should not be instantiated"); //$NON-NLS-1$
	}

}
